import { nodeResolve } from "@rollup/plugin-node-resolve";
import typescript from "@rollup/plugin-typescript";
import { createRequire } from "module";
import path from "node:path";
const require = createRequire(import.meta.url);
const packageJson = require("./package.json");

const bundlePackage = [
  "@qorebase/qore-apps",
  "@qorebase/app-runtime",
  path.resolve("/packages/runtime"),
];

const filename = packageJson.module.slice(
  "lib/".length,
  packageJson.module.indexOf(".")
);

/**
 * @type {import('rollup').RollupOptions}
 */
const rollupOptions = {
  input: `src/${filename}.tsx`,
  output: {
    file: `lib/${filename}.js`,
    format: "esm",
  },
  external: (id) => {
    return (
      id.includes("node_modules/") ||
      !(
        id.startsWith("/") ||
        id.startsWith(".") ||
        bundlePackage.some((pkg) => id.includes(pkg))
      )
    );
  },
  plugins: [
    nodeResolve({
      browser: true,
    }),
    typescript(),
  ],
};

export default rollupOptions;
